@@ -33,6 +33,13 @@ class Permissions(github.GithubObject.NonCompletableGithubObject):
     This class represents Permissionss as returned for example by http://developer.github.com/v3/todo
     """
 
+    def __repr__(self):
+        return self.get__repr__({
+            "admin": self._admin.value,
+            "pull": self._pull.value,
+            "push": self._push.value
+        })
+
     @property
     def admin(self):
         """
