@@ -47,6 +47,9 @@ class Hook(Framework.TestCase):
         self.assertEqual(self.hook.updated_at, datetime.datetime(2012, 5, 29, 18, 49, 47))
         self.assertEqual(self.hook.url, "https://api.github.com/repos/jacquev6/PyGithub/hooks/257993")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.hook.__repr__(), 'Hook(url="https://api.github.com/repos/jacquev6/PyGithub/hooks/257993", id=257993)')
+
     def testEditWithMinimalParameters(self):
         self.hook.edit("web", {"url": "http://foobar.com/hook"})
         self.assertEqual(self.hook.config, {"url": "http://foobar.com/hook"})
