@@ -67,7 +67,7 @@ class Issue(Framework.TestCase):
     def testEditWithAllParameters(self):
         user = self.g.get_user("jacquev6")
         milestone = self.repo.get_milestone(2)
-        self.issue.edit("Title edited by PyGithub", "Body edited by PyGithub", user, "open", milestone, ["Bug"])
+        self.issue.edit("Title edited by PyGithub", "Body edited by PyGithub", user, "open", milestone, ["Bug"], ["assigned1", "assigned2"])
         self.assertEqual(self.issue.assignee.login, "jacquev6")
         self.assertEqual(self.issue.body, "Body edited by PyGithub")
         self.assertEqual(self.issue.state, "open")
